@@ -3,5 +3,5 @@
 void Generator::classH(ostream &out) const
 {
     key(out);
-    out << "#include \"" << d_parser.classHeader() << "\"\n";
+    out << "#include \"" << d_options.classHeader() << "\"\n";
 }
