@@ -2,11 +2,12 @@
 #define _INCLUDED_GENERATOR_
 
 #include <vector>
-#include <map>
+#include <unordered_map>
 #include <string>
 #include <iosfwd>
 
 #include <bobcat/arg>
+#include <bobcat/stat>
 
 #include "../writer/writer.h"
 
@@ -17,11 +18,14 @@ class Options;
 class Generator
 {
     typedef void (Generator::*Inserter)(std::ostream &) const;
-    typedef std::map<std::string, Inserter>     Map;
+    typedef std::unordered_map<std::string, Inserter>     Map;
     typedef Map::value_type                     MapValue;
     typedef Map::const_iterator                 MapConstIter;
 
-    FBB::Arg &d_arg;
+    FBB::Arg   &d_arg;
+
+    mutable FBB::Stat   d_stat;
+
     Rules const &d_rules;
     Options &d_options;
 
@@ -37,6 +41,8 @@ class Generator
     bool d_debug;
     bool d_printTokens;
     
+    std::unordered_map<std::string, std::string> const &d_polymorphic; 
+
     mutable Writer d_writer;                // maintains its own const-ness
 
     static Map s_insert;
@@ -46,7 +52,8 @@ class Generator
 
 
     public:
-        Generator(Rules const &rules);
+        Generator(Rules const &rules, 
+             std::unordered_map<std::string, std::string> const &polymorphic); 
 
         void baseClassHeader() const;
         void classHeader() const;
@@ -54,7 +61,9 @@ class Generator
         void parseFunction() const;
 
     private:
-        void filter(std::istream &in, std::ostream &out) const;
+        void filter(std::istream &in, std::ostream &out, 
+                                        bool header = true) const;
+
         void insert(std::ostream &out) const;
         void key(std::ostream &out) const;          // show which $insert is
                                                     // called, just before the
@@ -80,6 +89,10 @@ class Generator
         void namespaceClose(std::ostream &out) const;
         void namespaceOpen(std::ostream &out) const;
         void namespaceUse(std::ostream &out) const;
+        void polymorphic(std::ostream &out) const;
+        void polymorphicImpl(std::ostream &out) const;
+        void polymorphicInline(std::ostream &out) const;
+        void polymorphicSpecializations(std::ostream &out) const;
         void preIncludes(std::ostream &out) const;
         void print(std::ostream &out) const;
         void requiredTokens(std::ostream &out) const;
