@@ -2,7 +2,7 @@
 
 void Generator::scannerObject(ostream &out) const
 {
-    if (d_parser.scanner().empty())
+    if (d_options.scannerInclude().empty())
         return;
 
     key(out);
