@@ -24,11 +24,16 @@ class Options
     bool        d_lines;
     bool        d_lspNeeded;
     bool        d_printTokens;
+    bool        d_polymorphic;
+    bool        d_strongTags;
 
     size_t      d_requiredTokens;
 
     std::string d_baseClassHeader;
     std::string d_baseClassSkeleton;
+    std::string d_polymorphicInline;
+    std::string d_polymorphicInlineSkeleton;
+    std::string d_polymorphicSkeleton;
     std::string d_classHeader;
     std::string d_className;
     std::string d_classSkeleton;
@@ -48,8 +53,9 @@ class Options
     std::string d_targetDirectory;
     std::string d_verboseName;
 
-
     static char s_defaultBaseClassSkeleton[];
+    static char s_defaultPolymorphicInlineSkeleton[];
+    static char s_defaultPolymorphicSkeleton[];
     static char s_defaultClassName[];
     static char s_defaultClassSkeleton[];
     static char s_defaultImplementationSkeleton[];
@@ -87,6 +93,9 @@ class Options
         void setLtype();
         void setNamespace();
         void setParsefunSource();
+        void setPolymorphicDecl();
+        void setPolymorphicInlineSkeleton();
+        void setPolymorphicSkeleton();
         void setPrintTokens();
         void setPreInclude();
         void setRequiredTokens(size_t nRequiredTokens);
@@ -99,8 +108,7 @@ class Options
         void setUnionDecl(std::string const &block);
         void setVerbosity();            // Prepare Msg for verbose output
         void unsetLines();
-
-        void finalizeAccessorVariables();
+        void unsetStrongTags();
 
         void showFilenames() const;
 
@@ -110,6 +118,8 @@ class Options
         bool errorVerbose() const;
         bool lines() const;
         bool lspNeeded() const;
+        bool polymorphic() const;
+        bool strongTags() const;
 
         size_t requiredTokens() const;
 
@@ -125,6 +135,8 @@ class Options
         std::string const &parseSkeleton() const;
         std::string const &parseSource() const;
         std::string const &preInclude() const;
+        std::string const &polymorphicInlineSkeleton() const;
+        std::string const &polymorphicSkeleton() const;
         std::string const &scannerInclude() const;
         std::string const &scannerMatchedTextFunction() const;
         std::string const &scannerTokenFunction() const;
@@ -152,6 +164,8 @@ class Options
         void setPath(std::string *dest, int optChar, bool targetDirOption, 
                       char const *optionName, std::string const &className, 
                       char const *suffix);
+
+        bool isFirstStypeDefinition() const;
 };
 
 inline bool Options::debug() const
@@ -209,6 +223,11 @@ inline bool Options::lspNeeded() const
     return d_lspNeeded;
 }
 
+inline bool Options::polymorphic() const
+{
+    return d_polymorphic;
+}
+
 inline std::string const &Options::ltype() const
 {
     return d_locationDecl;
@@ -229,6 +248,16 @@ inline std::string const &Options::parseSource() const
     return d_parsefunSource;
 }
 
+inline std::string const &Options::polymorphicInlineSkeleton() const
+{
+    return d_polymorphicInlineSkeleton;
+}
+
+inline std::string const &Options::polymorphicSkeleton() const
+{
+    return d_polymorphicSkeleton;
+}
+
 inline std::string const &Options::preInclude() const
 {
     return d_preInclude;
@@ -329,6 +358,16 @@ inline void Options::setParsefunSource()
     assign(&d_parsefunSource, "parsefun-source");
 }
 
+inline void Options::setPolymorphicInlineSkeleton()
+{
+    assign(&d_polymorphicInlineSkeleton, "polymorphic-inline-skeleton");
+}
+
+inline void Options::setPolymorphicSkeleton()
+{
+    assign(&d_polymorphicSkeleton, "polymorphic-skeleton");
+}
+
 inline void Options::setPreInclude()
 {
     assign(&d_preInclude, "baseclass-preinclude");
@@ -359,7 +398,6 @@ inline void Options::setSkeletonDirectory()
     assign(&d_skeletonDirectory, "skeleton-directory (-S)");
 }
 
-
 inline void Options::setTargetDirectory()
 {
     assign(&d_targetDirectory, "target-directory");
@@ -370,9 +408,14 @@ inline std::string const &Options::stype() const
     return d_stackDecl;
 }
 
+inline bool Options::strongTags() const
+{
+    return d_strongTags;
+}
+
+inline void Options::unsetStrongTags()
+{
+    d_strongTags = false;
+}
+
 #endif
-
-
-
-
-
