@@ -6,10 +6,13 @@
 // $insert scanner.h
 #include "../scanner/scanner.h"
 
+#include <unordered_map>
+
 class NonTerminal;
 class Terminal;
 class Symbol;
 class Options;
+class AtDollar;
 
 namespace FBB
 {
@@ -20,12 +23,23 @@ namespace FBB
 class Parser: public ParserBase
 {
             // actions to taken given tokens returned by the lexical scanner
-    typedef std::map<size_t, void (Parser::*)()> 
-            ActionMap;
-    typedef ActionMap::iterator 
-            Iterator;
-    typedef ActionMap::value_type 
-            Value;
+    typedef std::unordered_map<size_t, void (Parser::*)()>  ActionMap;
+    typedef ActionMap::iterator                             Iterator;
+    typedef ActionMap::value_type                           Value;
+
+    enum SemType
+    {
+        SINGLE,
+        UNION,
+        POLYMORPHIC
+    };
+
+    enum SemTag
+    {
+        NONE,
+        AUTO,
+        EXPLICIT,
+    };
 
             // data members that are self-explanatory are not explicitly
             // described here.
@@ -41,16 +55,16 @@ class Parser: public ParserBase
     Symtab      d_symtab;
 
     std::string d_expect;
-    std::string d_field;                    // %union field in <type> specs.
-    bool        d_typeDirective;            // true following %type
-    bool        d_unionDeclared;            // see setuniondecl.cc
+    std::string d_field;                // %union field in <type> specs.
+    bool        d_typeDirective;        // true following %type
+    SemType     d_semType;              // see set{union,polymorphic}decl.cc
     bool        d_negativeDollarIndices;
 
     Terminal::Association d_association;
 
-                                // used in processBlock() and sipIgnore()
-    std::vector<Block::Range>::const_reverse_iterator d_skipRbegin;
-    std::vector<Block::Range>::const_reverse_iterator d_skipRend;
+        // associations between type-identifiers and type-definitions of
+        // polymorphic semantic values
+    std::unordered_map<std::string, std::string> d_polymorphic;
 
     static size_t s_nHidden;          // number of hidden nonterminals
     static std::ostringstream s_hiddenName;
@@ -63,19 +77,40 @@ class Parser: public ParserBase
     static char s_locationValueStack[];  
                                     // name of the location value stack
                                     // used by the generated parser
+    static char s_locationValue[];
+                                    // name of the location value variable
+                                    // used by the generated parser (@0)
 
+    static char const s_stype__[];  // generic semantic value for POLYMORPHIC
+                                    
     public:
         Parser(Rules &rules);
         int parse();
         void cleanup();             // do cleanup following parse();
+        std::unordered_map<std::string, std::string> const &polymorphic() const;
 
     private:
+        void addPolymorphic(std::string const &tag, 
+                            std::string const &typeSpec);
+
         void addIncludeQuotes(std::string *target); // ensure ".." or <..> 
                                                     // around target name
         void checkEmptyBlocktype();
         void checkFirstType();
 
-        bool defaultReturn(size_t pos, Block &block);
+
+        bool noID(std::string const &) const;
+        bool idOK(std::string const &) const;
+        bool findTag(std::string const &tag) const;
+
+        void returnSingle(AtDollar const &atd) const;
+        std::string returnUnion(AtDollar const &atd) const;
+        std::string returnPolymorphic(AtDollar const &atd) const;
+ 
+        SemTag semTag(char const *label, AtDollar const &atd, 
+                     bool (Parser::*testID)(std::string const &) const) const;
+
+
         Symbol *defineNonTerminal(std::string const &name, 
                                   std::string const &stype);
         void definePathname(std::string *target);
@@ -90,23 +125,23 @@ class Parser: public ParserBase
         void setUnionDecl();
                                         
 
-        bool explicitElement(size_t pos, int nElements, Block &block);
-        bool explicitReturn(size_t pos, Block &block);
         size_t extractIndex(int *idx, size_t pos);
         size_t extractType(std::string *type, size_t pos, Block &block);
 
-        void handleAtSign(size_t idx, int nElements, Block &block);
-                                        // handle a location-value stack
+                                        // handles a location-value stack
                                         // reference (@) in a received action 
                                         // block
-        bool handleDollar(size_t idx, int nElements, Block &block);
-                                        // handle a semantic-value stack
+        void handleAtSign(Block &block, AtDollar const &atd, int nElements);
+
+                                        // handles a semantic-value stack
                                         // reference ($) in a received action 
                                         // block
+        bool handleDollar(Block &block, AtDollar const &atd, int nElements);
 
-        spSemBase handleProductionElements(spSemBase const &first, 
-                                           spSemBase const &second);
-        void handleProductionElement(spSemBase const &last);
+
+        STYPE__ handleProductionElements(STYPE__ &first, 
+                                         STYPE__ const &second);
+        void handleProductionElement(STYPE__ &last);
 
 
         void installAction(Block &block);
@@ -117,11 +152,22 @@ class Parser: public ParserBase
         void nestedBlock(Block &block); // define inner block as pseudo N
 
         std::string nextHiddenName();
-        void noDefaultTypeWarning();
+
+            // may generate error or warning:
+        void negativeIndex(AtDollar const &atd) const;
+
+        void warnAutoOverride(AtDollar const &atd) const;
+        void warnAutoIgnored(char const *typeOrField, 
+                             AtDollar const &atd) const;
+        void warnUntaggedValue(AtDollar const &atd) const;
+
+        // generating emsgs:
+        bool errIndexTooLarge(AtDollar const &atd, int nElements) const;
+        void errNoSemantic(char const *label, AtDollar const &atd,
+                                              std::string const &id) const;
 
         void setStart();
-
-        bool numberedElement(size_t pos, int nElements, Block &block);
+        void setPolymorphicDecl();
 
         void openRule(std::string const &ruleName);
 
@@ -130,9 +176,14 @@ class Parser: public ParserBase
 
         NonTerminal *requireNonTerminal(std::string const &name);
 
-        size_t skipIgnore(size_t pos);
         bool substituteBlock(int nElements, Block &block);
 
+                                        // saves the default $1 value
+                                        // at the beginning of a mid-rule
+                                        // action block (in substituteBlock)
+        void saveDollar1(Block &block, int offset);
+
+
         Symbol *useSymbol();
         Terminal *useTerminal();
 
@@ -147,38 +198,15 @@ class Parser: public ParserBase
         int lookup(bool recovery);
         void nextToken();
         void print__();
-                                        // used in, e.g., explicitElement()
+                                        // used in, e.g., handleDollar
                                         // to obtain # elements for
                                         // end- or mid-rule actions
-        static size_t nComponents(int nElements);
+        static int nComponents(int nElements);
 };
 
-// $insert lex
-inline int Parser::lex()
+inline std::unordered_map<std::string, std::string> const &Parser::polymorphic() const
 {
-    return d_scanner.lex();
-}
-
-inline void Parser::print()
-{
-    if (d_arg.option('T'))
-        print__();
-}
-
-
-inline void Parser::setNegativeDollarIndices()
-{
-    d_negativeDollarIndices = true;
-}        
-
-inline void Parser::setExpectedConflicts()
-{
-    Rules::setExpectedConflicts(d_scanner.number());
-}
-
-inline size_t Parser::nComponents(int nElements)
-{
-    return nElements >= 0 ? nElements : -nElements - 1;
+    return d_polymorphic;
 }
 
 #endif
