@@ -14,6 +14,8 @@ namespace // anonymous
 
 $insert namespace-open
 
+$insert polymorphic
+
 class \@Base
 {
     public:
@@ -98,6 +100,8 @@ $insert 4 debug "ERROR(): Forced error condition"
     throw UNEXPECTED_TOKEN__;
 }
 
+$insert polymorphicInline
+
 // As a convenience, when including ParserBase.h its symbols are available as
 // symbols in the class Parser, too.
 #define \@ \@Base
